@@ -241,24 +241,25 @@ class BeoPlay(object):
             await self.async_postReq('PUT',BEOPLAY_URL_MUTE, {"muted":False})
 
     async def async_play(self):
-        await self.async_postReq('POST',BEOPLAY_URL_PLAY,'')
-        await self.async_postReq('POST',BEOPLAY_URL_PLAY + BEOPLAY_URL_RELEASE,'')
+        await self.async_postReq('POST',BEOPLAY_URL_PLAY, {})
 
     async def async_pause(self):
-        await self.async_postReq('POST',BEOPLAY_URL_PAUSE,'')
-        await self.async_postReq('POST',BEOPLAY_URL_PAUSE+BEOPLAY_URL_RELEASE,'')
+        await self.async_postReq('POST',BEOPLAY_URL_PAUSE, {})
 
     async def async_stop(self):
-        await self.async_postReq('POST',BEOPLAY_URL_STOP,'')
-        await self.async_postReq('POST',BEOPLAY_URL_STOP+BEOPLAY_URL_RELEASE,'')
+        await self.async_postReq('POST',BEOPLAY_URL_STOP, {})
 
     async def async_next(self):
-        await self.async_postReq('POST',BEOPLAY_URL_FORWARD,'')
-        await self.async_postReq('POST',BEOPLAY_URL_FORWARD+BEOPLAY_URL_RELEASE,'')
+        await self.async_postReq('POST',BEOPLAY_URL_STEPUP, {})
 
     async def async_prev(self):
-        await self.async_postReq('POST',BEOPLAY_URL_BACKWARD,'')
-        await self.async_postReq('POST',BEOPLAY_URL_BACKWARD+BEOPLAY_URL_RELEASE,'')
+        await self.async_postReq('POST',BEOPLAY_URL_STEPDOWN, {})
+
+    async def async_shuffle(self):
+        await self.async_postReq('POST',BEOPLAY_URL_SHUFFLE, {})
+
+    async def async_repeat(self):
+        await self.async_postReq('POST',BEOPLAY_URL_REPEAT, {})
 
     async def async_standby(self):
         await self.async_postReq('PUT',BEOPLAY_URL_STANDBY, {"standby":{"powerState":"standby"}})
@@ -285,10 +286,10 @@ class BeoPlay(object):
             i += 1
 
     async def async_join_experience(self):
-        await self.async_postReq('POST',BEOPLAY_URL_JOIN_EXPERIENCE,'')
+        await self.async_postReq('POST',BEOPLAY_URL_JOIN_EXPERIENCE)
 
     async def async_leave_experience(self):
-        await self.async_postReq('DELETE',BEOPLAY_URL_LEAVE_EXPERIENCE, '')
+        await self.async_postReq('DELETE',BEOPLAY_URL_LEAVE_EXPERIENCE)
 
     async def async_play_queue_item(self, instantplay: bool, queueItem: dict):
         """ Play a queue item, from Deezer, TuneIn or DLNA. 
@@ -442,23 +443,18 @@ class BeoPlay(object):
 
     def Play(self):
         self._postReq('POST',BEOPLAY_URL_PLAY,'')
-        self._postReq('POST',BEOPLAY_URL_PLAY + BEOPLAY_URL_RELEASE,'')
 
     def Pause(self):
         self._postReq('POST',BEOPLAY_URL_PAUSE,'')
-        self._postReq('POST',BEOPLAY_URL_PAUSE+BEOPLAY_URL_RELEASE,'')
 
     def Stop(self):
         self._postReq('POST',BEOPLAY_URL_STOP,'')
-        self._postReq('POST',BEOPLAY_URL_STOP+BEOPLAY_URL_RELEASE,'')
 
     def Next(self):
-        self._postReq('POST',BEOPLAY_URL_FORWARD,'')
-        self._postReq('POST',BEOPLAY_URL_FORWARD+BEOPLAY_URL_RELEASE,'')
+        self._postReq('POST',BEOPLAY_URL_STEPUP,'')
 
     def Prev(self):
-        self._postReq('POST',BEOPLAY_URL_BACKWARD,'')
-        self._postReq('POST',BEOPLAY_URL_BACKWARD+BEOPLAY_URL_RELEASE,'')
+        self._postReq('POST',BEOPLAY_URL_STEPDOWN,'')
 
     def Standby(self):
         self._postReq('PUT',BEOPLAY_URL_STANDBY, {"standby":{"powerState":"standby"}})
